@@ -113,26 +113,27 @@ class DefaultIcon(GObject.GObject):
         width = art_size.width * scale
         height = art_size.height * scale
 
-        icon = Gtk.IconTheme.get_default().load_icon(icon_type.value,
-                                                     max(width, height) / 4,
-                                                     0)
+        # TODO: Load icon async.
+        default_theme = Gtk.IconTheme.get_default()
+        icon_info = default_theme.lookup_icon_for_scale(
+            icon_type.value, max(art_size.width, art_size.height), scale, 0)
+        icon = icon_info.load_icon()
 
-        # create an empty pixbuf with the requested size
-        result = GdkPixbuf.Pixbuf.new(icon.get_colorspace(),
-                                      True,
-                                      icon.get_bits_per_sample(),
-                                      width,
-                                      height)
+        result = GdkPixbuf.Pixbuf.new(
+            icon.get_colorspace(), True, icon.get_bits_per_sample(), width,
+            height)
         result.fill(0xffffffff)
 
-        icon.composite(result,
-                       icon.get_width() * 3 / 2,
-                       icon.get_height() * 3 / 2,
-                       icon.get_width(),
-                       icon.get_height(),
-                       icon.get_width() * 3 / 2,
-                       icon.get_height() * 3 / 2,
-                       1, 1, GdkPixbuf.InterpType.HYPER, 0x33)
+        icon_scale = 0.33
+
+        def icon_offset(x):
+            return int((x / 2) - (x * icon_scale * 0.5))
+
+        icon.composite(
+            result, icon_offset(width), icon_offset(height),
+            width * icon_scale, height * icon_scale, icon_offset(width),
+            icon_offset(height), icon_scale, icon_scale,
+            GdkPixbuf.InterpType.HYPER, 0x77)
 
         icon_surface = _make_icon_frame(result, art_size, scale)
 
@@ -302,7 +303,6 @@ class Art(GObject.GObject):
                 GLib.filename_to_uri(thumb_file.get_path(), None))
 
     @GObject.Property
-    @log
     def surface(self):
         if self._surface is None:
             self._surface = DefaultIcon().get(
@@ -336,7 +336,6 @@ class ArtImage(Art):
         self._image.set_from_surface(self._surface)
 
     @GObject.Property
-    @log
     def image(self):
         """Returns the image object of the ArtImage class
 
@@ -347,7 +346,6 @@ class ArtImage(Art):
         return self._image.set_from_surface(self._surface)
 
     @image.setter
-    @log
     def image(self, image):
         """Set the image of the Art class instance""
 
