@@ -24,11 +24,11 @@
 
 import logging
 from gettext import gettext as _
-from gi.repository import Gdk, GLib, Gtk, Pango
+from gi.repository import Gdk, Gtk, Pango
 
 from gnomemusic import log
 from gnomemusic.grilo import grilo
-from gnomemusic.player import DiscoveryStatus
+from gnomemusic.player import ValidationStatus, PlayerPlaylist
 from gnomemusic.views.baseview import BaseView
 import gnomemusic.utils as utils
 
@@ -63,6 +63,7 @@ class SongsView(BaseView):
 
         self.player = player
         self.player.connect('song-changed', self._update_model)
+        self.player.connect('song-validated', self._on_song_validated)
 
     @log
     def _setup_view(self):
@@ -149,15 +150,15 @@ class SongsView(BaseView):
             cell.props.text = utils.get_album_title(item)
 
     def _on_list_widget_icon_render(self, col, cell, model, itr, data):
-        track_uri = self.player.url
-        if not track_uri:
+        if not self.player.playing_playlist(PlayerPlaylist.Type.SONGS, None):
             cell.props.visible = False
-            return
+            return False
 
-        if model[itr][11] == DiscoveryStatus.FAILED:
+        current_song = self.player.props.current_song
+        if model[itr][11] == ValidationStatus.FAILED:
             cell.props.icon_name = self._error_icon_name
             cell.props.visible = True
-        elif model[itr][5].get_url() == track_uri:
+        elif model[itr][5].get_id() == current_song.get_id():
             cell.props.icon_name = self._now_playing_icon_name
             cell.props.visible = True
         else:
@@ -169,7 +170,7 @@ class SongsView(BaseView):
                 and not self.props.selection_mode):
             self.model.clear()
             self._offset = 0
-            GLib.idle_add(self.populate)
+            self.populate()
             grilo.changes_pending['Songs'] = False
 
     @log
@@ -202,9 +203,9 @@ class SongsView(BaseView):
             return
 
         itr = self.model.get_iter(path)
-        if self.model[itr][8] != self._error_icon_name:
-            self.player.set_playlist('Songs', None, self.model, itr)
-            self.player.play()
+        self.player.set_playlist(
+            PlayerPlaylist.Type.SONGS, None, self.model, itr)
+        self.player.play()
 
     @log
     def _on_view_clicked(self, treeview, event):
@@ -227,20 +228,18 @@ class SongsView(BaseView):
             self._update_header_from_selection(len(self.get_selected_songs()))
 
     @log
-    def _update_model(self, player, playlist, current_iter):
-        """Updates model when the track changes
+    def _update_model(self, player, position):
+        """Updates model when the song changes
 
-        :param player: The main player object
-        :param playlist: The current playlist object
-        :param current_iter: Iter of the current displayed song
+        :param Player player: The main player object
+        :param int position: current song position
         """
         if self._iter_to_clean:
             self.model[self._iter_to_clean][10] = False
-        if not player.playing_playlist('Songs', None):
+        if not player.playing_playlist(PlayerPlaylist.Type.SONGS, None):
             return False
 
-        pos_str = playlist.get_path(current_iter).to_string()
-        iter_ = self.model.get_iter_from_string(pos_str)
+        iter_ = self.model.get_iter_from_string(str(position))
         self.model[iter_][10] = True
         path = self.model.get_path(iter_)
         self._view.scroll_to_cell(path, None, False, 0., 0.)
@@ -248,6 +247,14 @@ class SongsView(BaseView):
             self._iter_to_clean = iter_.copy()
         return False
 
+    @log
+    def _on_song_validated(self, player, index, status):
+        if not player.playing_playlist(PlayerPlaylist.Type.SONGS, None):
+            return
+
+        iter_ = self.model.get_iter_from_string(str(index))
+        self.model[iter_][11] = status
+
     def _add_item(self, source, param, item, remaining=0, data=None):
         """Adds track item to the model"""
         if not item and not remaining:
@@ -273,7 +280,7 @@ class SongsView(BaseView):
         self._init = True
         if grilo.tracker:
             self._window.notifications_popup.push_loading()
-            GLib.idle_add(grilo.populate_songs, self._offset, self._add_item)
+            grilo.populate_songs(self._offset, self._add_item)
 
     @log
     def get_selected_songs(self, callback=None):
