@@ -1,4 +1,4 @@
-# Copyright © 2018 The GNOME Music developers
+# Copyright 2018 The GNOME Music developers
 #
 # GNOME Music is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ from gnomemusic import log
 from gnomemusic.albumartcache import Art, DefaultIcon
 
 
-class CoverStack(GObject.GObject):
+class CoverStack(Gtk.Stack):
     """Provides a smooth transition between image states
 
     Uses a Gtk.Stack to provide an in-situ transition between an image
@@ -36,36 +36,62 @@ class CoverStack(GObject.GObject):
     or in between songs.
     """
 
+    __gtype_name__ = 'CoverStack'
+
     __gsignals__ = {
         'updated': (GObject.SignalFlags.RUN_FIRST, None, ())
     }
 
     _default_icon = DefaultIcon()
 
+    def __repr__(self):
+        return '<CoverStack>'
+
     @log
-    def __init__(self, stack, size):
+    def __init__(self, size=Art.Size.MEDIUM):
+        """Initialize the CoverStack
+
+        :param Art.Size size: The size of the art used for the cover
+        """
         super().__init__()
 
-        self._size = size
-        self._stack = stack
-        self._stack.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
-        self._scale = self._stack.get_scale_factor()
+        self._size = None
         self._handler_id = None
 
-        self._loading_icon = self._default_icon.get(
-            DefaultIcon.Type.LOADING, self._size, self._scale)
-
-        self._loading_cover = Gtk.Image.new_from_surface(self._loading_icon)
-
+        self._loading_cover = Gtk.Image()
         self._cover_a = Gtk.Image()
         self._cover_b = Gtk.Image()
 
-        self._stack.add_named(self._loading_cover, "loading")
-        self._stack.add_named(self._cover_a, "A")
-        self._stack.add_named(self._cover_b, "B")
+        self.add_named(self._loading_cover, "loading")
+        self.add_named(self._cover_a, "A")
+        self.add_named(self._cover_b, "B")
 
-        self._stack.set_visible_child_name("loading")
-        self._stack.show_all()
+        self.props.size = size
+        self.props.transition_type = Gtk.StackTransitionType.CROSSFADE
+        self.props.visible_child_name = "loading"
+
+        self.show_all()
+
+    @GObject.Property(type=object, flags=GObject.ParamFlags.READWRITE)
+    def size(self):
+        """Size of the cover
+
+        :returns: The size used
+        :rtype: Art.Size
+        """
+        return self._size
+
+    @size.setter
+    def size(self, value):
+        """Set the cover size
+
+        :param Art.Size value: The size to use for the cover
+        """
+        self._size = value
+
+        icon = self._default_icon.get(
+            DefaultIcon.Type.LOADING, self.props.size, self.props.scale_factor)
+        self._loading_cover.props.surface = icon
 
     @log
     def update(self, media):
@@ -74,9 +100,9 @@ class CoverStack(GObject.GObject):
         Update the stack with the art retrieved from the given media.
         :param Grl.Media media: The media object
         """
-        self._active_child = self._stack.get_visible_child_name()
+        self._active_child = self.props.visible_child_name
 
-        art = Art(self._size, media, self._scale)
+        art = Art(self.props.size, media, self.props.scale_factor)
         self._handler_id = art.connect('finished', self._art_retrieved)
         art.lookup()
 
@@ -84,10 +110,10 @@ class CoverStack(GObject.GObject):
     def _art_retrieved(self, klass):
         klass.disconnect(self._handler_id)
         if self._active_child == "B":
-            self._cover_a.set_from_surface(klass.surface)
-            self._stack.set_visible_child_name("A")
+            self._cover_a.props.surface = klass.surface
+            self.props.visible_child_name = "A"
         else:
-            self._cover_b.set_from_surface(klass.surface)
-            self._stack.set_visible_child_name("B")
+            self._cover_b.props.surface = klass.surface
+            self.props.visible_child_name = "B"
 
         self.emit('updated')
